@@ -20,6 +20,7 @@
 
 #include "defaultdevice.h"
 #include "libastro.h"
+#include "indipropertyswitch.h"
 #include <libnova/julian_day.h>
 
 #include <string>
@@ -745,6 +746,14 @@ class Telescope : public DefaultDevice
         ISwitch MovementWES[2];
         ISwitchVectorProperty MovementWESP;
 
+        // Reverse NS or WE
+        INDI::PropertySwitch ReverseMovementSP {2};
+        enum
+        {
+            REVERSE_NS,
+            REVERSE_WE
+        };
+
         // Slew Rate
         ISwitchVectorProperty SlewRateSP;
         ISwitch *SlewRateS {nullptr};
@@ -933,7 +942,7 @@ class Telescope : public DefaultDevice
         bool m_simulatePierSide;    // use setSimulatePierSide and getSimulatePierSide for public access
 
         // 100 millisecond of arc or time.
-        static constexpr double EQ_NOTIFY_THRESHOLD {1.0/(60*60*10)};
+        static constexpr double EQ_NOTIFY_THRESHOLD {1.0 / (60 * 60 * 10)};
 };
 
 }
